@@ -1,10 +1,9 @@
 import os
-from time import sleep
-from pymk import extra
 from pymk.script import import_mkfile
 from pymk.tests.base import PymkTestCase
 import pymk.error as Perror
 
+
 class TaskTest(PymkTestCase):
 
     def test_no_mkfile(self):
@@ -49,6 +48,15 @@ class TaskTest(PymkTestCase):
         self.touch('a.out')
         self._pymk_runtask(['task_5'])
 
+    def test_bad_task(self):
+        self._template('one_task_bad', 'mkfile.py')
+        self.assertRaises(Perror.NoDependencysInAClass, self._import_mkfile)
+
+    def test_NotADependencyError(self):
+        self._template('one_task_bad_depedency', 'mkfile.py')
+        self.assertRaises(Perror.NotADependencyError, self._import_mkfile)
+
+
 class TaskForcing(PymkTestCase):
 
     def test_forcing_file_changed(self):
@@ -61,7 +69,8 @@ class TaskForcing(PymkTestCase):
 
         self._args.force = True
         self._pymk_runtask(['task_17c', 'task_17b', 'task_17a', 'task_17a'])
-        self._pymk_runtask(['task_17c', 'task_17b', 'task_17a', 'task_17a', 'task_17a'])
+        self._pymk_runtask(
+            ['task_17c', 'task_17b', 'task_17a', 'task_17a', 'task_17a'])
 
     def test_dependency_forcing_file_changed(self):
         self._template('three_task_with_force', 'mkfile.py')
@@ -73,7 +82,8 @@ class TaskForcing(PymkTestCase):
         self._pymk_runtask(['task_17c', 'task_17b', 'task_17a'])
 
         self._args.force = True
-        self._pymk_runtask(['task_17c', 'task_17b', 'task_17a', 'task_17c', 'task_17b', 'task_17a'])
+        self._pymk_runtask(['task_17c', 'task_17b', 'task_17a',
+                           'task_17c', 'task_17b', 'task_17a'])
         self._pymk_runtask(['task_17c', 'task_17b', 'task_17a', 'task_17c', 'task_17b', 'task_17a', 'task_17c', 'task_17b', 'task_17a'])
 
     def test_forcing_file_exist(self):
@@ -86,7 +96,8 @@ class TaskForcing(PymkTestCase):
 
         self._args.force = True
         self._pymk_runtask(['task_18c', 'task_18b', 'task_18a', 'task_18a'])
-        self._pymk_runtask(['task_18c', 'task_18b', 'task_18a', 'task_18a', 'task_18a'])
+        self._pymk_runtask(
+            ['task_18c', 'task_18b', 'task_18a', 'task_18a', 'task_18a'])
 
     def test_dependency_forcing_file_exist(self):
         self._template('three_task_with_force_2', 'mkfile.py')
@@ -98,9 +109,11 @@ class TaskForcing(PymkTestCase):
         self._pymk_runtask(['task_18c', 'task_18b', 'task_18a'])
 
         self._args.force = True
-        self._pymk_runtask(['task_18c', 'task_18b', 'task_18a', 'task_18c', 'task_18b', 'task_18a'])
+        self._pymk_runtask(['task_18c', 'task_18b', 'task_18a',
+                           'task_18c', 'task_18b', 'task_18a'])
         self._pymk_runtask(['task_18c', 'task_18b', 'task_18a', 'task_18c', 'task_18b', 'task_18a', 'task_18c', 'task_18b', 'task_18a'])
 
+
 class TaskDependencyFileExistsTest(PymkTestCase):
     def test_make_no_outputfile(self):
         self._template('three_task_dependency_exists2', 'mkfile.py')
@@ -183,6 +196,7 @@ class TaskDependencyFileExistsTest(PymkTestCase):
         self._pymk_runtask(['task_6a'])
         self._pymk_runtask(['task_6a'])
 
+
 class TaskDependencyFileChangedTest(PymkTestCase):
     def test_make_once(self):
         self._template('two_task_dependency_changed1', 'mkfile.py')
@@ -226,12 +240,16 @@ class TaskDependencyFileChangedTest(PymkTestCase):
         self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a'])
 
         self.touch('c.out')
-        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a', 'task_12b', 'task_12a'])
-        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a', 'task_12b', 'task_12a'])
+        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a',
+                           'task_12a', 'task_12b', 'task_12a'])
+        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a',
+                           'task_12a', 'task_12b', 'task_12a'])
 
         os.unlink('b.out')
-        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a', 'task_12b', 'task_12a', 'task_12b', 'task_12a'])
-        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a', 'task_12b', 'task_12a', 'task_12b', 'task_12a'])
+        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a',
+                           'task_12b', 'task_12a', 'task_12b', 'task_12a'])
+        self._pymk_runtask(['task_12c', 'task_12b', 'task_12a', 'task_12a',
+                           'task_12b', 'task_12a', 'task_12b', 'task_12a'])
 
     def test_make_three_tasks_fail1(self):
         self._template('three_task_dependency_changed2', 'mkfile.py')
@@ -251,7 +269,8 @@ class TaskDependencyFileChangedTest(PymkTestCase):
 
         os.unlink('b.out')
         self.assertRaises(Perror.TaskMustHaveOutputFile, self._pymk)
-        self._check_output_file(['task_13c', 'task_13b', 'task_13b', 'task_13b'])
+        self._check_output_file(
+            ['task_13c', 'task_13b', 'task_13b', 'task_13b'])
 
     def test_make_three_tasks_fail2(self):
         self._template('three_task_dependency_changed3', 'mkfile.py')
@@ -291,7 +310,8 @@ class TaskDependencyFileChangedTest(PymkTestCase):
 
         os.unlink('b.out')
         self.assertRaises(Perror.TaskMustHaveOutputFile, self._pymk)
-        self._check_output_file(['task_15c', 'task_15c', 'task_15c', 'task_15c'])
+        self._check_output_file(
+            ['task_15c', 'task_15c', 'task_15c', 'task_15c'])
 
     def test_uptodate(self):
         self._template('two_task_dependency_changed1', 'mkfile.py')
